#!/bin/sh
#
###############################################################################
# NOM: iptable-ipmasquerading-2.sh
#
# COMMENTAIRE : Exemple d'utilisation de l'IP masquerading
#               paradise.sky.net va pouvoir aller sur web.internet.net
#               Mais ici, l'inverse est aussi vrai, grce  une erreur
#               introduite volontairement sur la cible par dfaut de la chane
#               "FORWARD" de la table "Filter"
# 
# Ce script fait partie du document :
#        "Firewall et scurit d'un rseau personnel sous Linux"
#        http://olivieraj.free.fr/fr/linux/information/firewall/
#
# Auteur: Olivier ALLARD-JACQUIN (http://olivieraj.free.fr/)
# Cr le: 2003/07/06                     Dernire modification le : 2003/07/06
###############################################################################

# Chargement des modules du suivi de connexion
modprobe ip_conntrack        ; # Module principal du suivi de connexion
modprobe ip_conntrack_ftp    ; # Module du suivi de connexion FTP
modprobe ip_conntrack_irc    ; # Module du suivi de connexion IRC

# Suppression de toutes les chanes pr-dfinies de la table FILTER
iptables -t filter -F

# Suppression de toutes les chanes utilisateur de la table FILTER
iptables -t filter -X

# Par defaut, toute les paquets de la table FILTER sont dtruits
iptables -t filter -P INPUT DROP
iptables -t filter -P OUTPUT DROP
# Erreur volontaire mettant en pril la scurit du rseau ("ACCEPT" au lieu de "DROP")
iptables -t filter -P FORWARD ACCEPT

# Autorise le port 6000 sur Phoenix (phoenix0 et phoenix1), afin de supporter
# le export display pour les besoins de la confrence
# En temps normal, ces lignes DOIVENT tres supprimes!!!
iptables -t filter -A OUTPUT -p 6   --sport 6000 -j ACCEPT  ; # -p 6   <=> protocole X11
iptables -t filter -A OUTPUT -p tcp --sport 6000 -j ACCEPT  ; # -p tcp <=> protocole TCP
iptables -t filter -A INPUT  -p 6   --dport 6000 -j ACCEPT
iptables -t filter -A INPUT  -p tcp --dport 6000 -j ACCEPT

# Autorise l'interface loopback  dialoguer avec elle-mme
iptables -t filter -A OUTPUT -o lo -s 0.0.0.0/0 -d 0.0.0.0/0 -j ACCEPT
iptables -t filter -A INPUT  -i lo -s 0.0.0.0/0 -d 0.0.0.0/0 -j ACCEPT

# Autorise les connexions avec le rseau 192.168.0.0/24 connect  l'interface eth0
iptables -t filter -A OUTPUT -o eth0 -s 192.168.0.0/24 -d 192.168.0.0/24 -j ACCEPT
iptables -t filter -A INPUT  -i eth0 -s 192.168.0.0/24 -d 192.168.0.0/24 -j ACCEPT

################################################################################
# IP masquerading
################################################################################

# Chargement des modules du NAT
modprobe iptable_nat    ; # Module principal du NAT
modprobe ip_nat_ftp     ; # Module du NAT FTP
modprobe ip_nat_irc     ; # Module du NAT IRC

# Suppression de toutes les chanes pr-dfinies de la table NAT
iptables -t nat -F

# Suppression de toutes les chanes utilisateur de la table NAT
iptables -t nat -X 

# Par defaut, toute les paquets de la table NAT sont ACCEPTES
iptables -t nat -P PREROUTING  ACCEPT
iptables -t nat -P POSTROUTING ACCEPT
iptables -t nat -P OUTPUT      ACCEPT

# Autorise les paquet  aller d'une interface rseau  l'autre
iptables -t filter -A FORWARD -i eth0 -o eth1 -s 192.168.0.0/24 -d 0.0.0.0/0 -m state --state ! INVALID           -j ACCEPT
iptables -t filter -A FORWARD -i eth1 -o eth0 -s 0.0.0.0/0 -d 192.168.0.0/24 -m state --state ESTABLISHED,RELATED -j ACCEPT

# Demande  la table NAT de modifier les paquets sortants
iptables -t nat -A POSTROUTING -o eth1 -s 192.168.0.0/24 -j MASQUERADE

# Activation du NAT dans le kernel
echo 1 > /proc/sys/net/ipv4/ip_forward
